#
# spec file for package openhantek
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openhantek
Version:        3.3.3
Release:        1.2
Summary:        Software for Hantek DSO6022 USB digital signal oscilloscopes
License:        GPL-3.0-or-later
Group:          Hardware/Other
URL:            http://openhantek.org/
Source:         https://github.com/OpenHantek/OpenHantek6022/archive/refs/tags/%{version}.tar.gz#/%name-%version.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Widgets) >= 5.4
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libusb-1.0)

%description
OpenHantek6022 is a free software for Hantek DSO6022 USB digital signal
oscilloscopes that is actively developed on
github.com/OpenHantek/OpenHantek6022 - but only for Hantek 6022BE/BL and
compatible scopes (Voltcraft, Darkwire, Protek, Acetech, etc.).

%prep
%autosetup -n OpenHantek6022-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install
%suse_update_desktop_file OpenHantek Development Debugger Education Engineering DataVisualization Qt

%files
%license LICENSE
%doc CHANGELOG README README.md
%{_bindir}/OpenHantek
%{_prefix}/lib/udev/rules.d/60-openhantek.rules
%{_datadir}/applications/OpenHantek.desktop
%{_datadir}/doc/%{name}/
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%{_datadir}/icons/hicolor/48x48/apps/OpenHantek.png
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/OpenHantek.svg

%changelog
* Mon Sep  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.3.3:
  * fix #376 "vector's iterator dereference out of range"
  * due to low issue activity remove the automatic stale workflow
  * fix #374 start / stop roll mode sampling (almost) immediately
  * split 'samplerateChanged' event handler; remove useless
    'this->'
  * update translations
  * Fixes #363, refs #365. Splitted
    HorizontalDock::timebaseChanged event handler from doing
    operations on dsoControl and dsoWidget in the same callback.
    Now there two callback and each uses the Widget it operates
    on. [875a8dc]
  * Add support for YiXingDianZiKeJi YX-DSO (MSDO)
  * show error message when screenshot or export file write fails
  * MSDO calibration file update from real device.
  * Add support for YiXingDianZiKeJi YX-DSO (MSDO)
  * change dB suffix with "Ok" or "Apply"
  * more cleanup
  * i18n for dB suffix "V", "u", "m"; silence more warnings
  * fix mac build
  * rearrange GH runner steps
  * move "Demo Mode" button to dialog button box at the window
    bottom
  * fix build versioning
* Sat Apr 15 2023 Dirk Müller <dmueller@suse.com>
- update to 3.3.2.2:
  * Various warning and other bugfixes
  * Full Changelog:
    https://github.com/OpenHantek/OpenHantek6022/compare/3.3.2.1...3.3.2.2
* Tue Jan 31 2023 Dirk Müller <dmueller@suse.com>
- update to 3.3.2.1:
  * This version is a fix that allows building directly from zip / tgz
    sources without having to use git.
  * After some hacking around GH runner issues finally the _New Year
    Release_.
  * Full Changelog:
    https://github.com/OpenHantek/OpenHantek6022/compare/3.3.1...3.3.2
* Fri Dec  2 2022 Michal Suchanek <msuchanek@suse.com>
- OpenHantek6022 3.3.1
